@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,10 +13,12 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = ();
 
 sub GetDisplayPath {
-    return 'Operating System';
+    return Translatable('Operating System');
 }
 
 sub Run {
@@ -41,13 +43,13 @@ sub Run {
 
     if ($KernelVersion) {
         $Self->AddResultInformation(
-            Label => 'Kernel Version',
+            Label => Translatable('Kernel Version'),
             Value => $KernelVersion,
         );
     }
     else {
         $Self->AddResultProblem(
-            Label => 'Kernel Version',
+            Label => Translatable('Kernel Version'),
             Value => $KernelVersion,
             Value => 'Could not determine kernel version.',
         );
@@ -56,16 +58,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<https://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
-
-=cut
-
 1;
