@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::System::Ticket',
 );
 
 sub GetDisplayPath {
-    return 'OTRS';
+    return Translatable('OTRS');
 }
 
 sub Run {
@@ -33,14 +35,14 @@ sub Run {
 
     if ( $OpenTickets > 8000 ) {
         $Self->AddResultWarning(
-            Label   => 'Open Tickets',
+            Label   => Translatable('Open Tickets'),
             Value   => $OpenTickets,
-            Message => 'You should not have more than 8,000 open tickets in your system.',
+            Message => Translatable('You should not have more than 8,000 open tickets in your system.'),
         );
     }
     else {
         $Self->AddResultOk(
-            Label => 'Open Tickets',
+            Label => Translatable('Open Tickets'),
             Value => $OpenTickets,
         );
     }
@@ -48,16 +50,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<https://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
-
-=cut
-
 1;
