@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/\n";
+// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -8,7 +8,7 @@
 
 "use strict";
 
-var OTRS = OTRS || {};
+var Core = Core || {};
 Core.UI = Core.UI || {};
 
 Core.UI.Popup = (function (Namespace) {
@@ -21,18 +21,18 @@ Core.UI.Popup = (function (Namespace) {
             var ExpectedProfiles = {
                 'Default': {
                     WindowURLParams: "dependent=yes,location=no,menubar=no,resizable=yes,scrollbars=yes,status=no,toolbar=no",
-                    Left:            100,
-                    Top:             100,
-                    Width:           1000,
-                    Height:          700
+                    Left: 100,
+                    Top: 100,
+                    Width: 1040,
+                    Height: 700
                 }
             };
 
             deepEqual(Core.UI.Popup.ProfileList(), ExpectedProfiles, 'Default profile list');
 
-            ExpectedProfiles['CustomLarge'] = "dependent=yes,height=700,left=100,top=100,location=no,menubar=no,resizable=yes,scrollbars=yes,status=no,toolbar=no,width=1000";
+            ExpectedProfiles.CustomLarge = "dependent=yes,height=700,left=100,top=100,location=no,menubar=no,resizable=yes,scrollbars=yes,status=no,toolbar=no,width=1000";
 
-            Core.UI.Popup.ProfileAdd('CustomLarge', ExpectedProfiles['CustomLarge']);
+            Core.UI.Popup.ProfileAdd('CustomLarge', ExpectedProfiles.CustomLarge);
 
             deepEqual(Core.UI.Popup.ProfileList(), ExpectedProfiles, 'Modified profile list');
         });
